@@ -98,7 +98,14 @@ WE SHOULD USE 410 status instead
 */
 remoteCallFailed = function(err, req) {
     cw.log(err);
-    if (!err.startswith('--GONE--:')){
-        oldRemoteCallFailed(err, req);
+    try {
+        if (err.startswith('--GONE--:')) {
+            // we edited an entity that's now gone
+            return
+        }
+    } catch (e) {
+        // err was not a string or does not support .startswith
+        // let's do nothing
     }
+    oldRemoteCallFailed(err, req);
 };
